@@ -66,6 +66,32 @@ async fn test_get_api_state() {
     assert!(server_handle.await.unwrap_err().is_cancelled());
 }
 
+#[tokio::test]
+#[serial_test::serial]
+async fn test_get_api_ref() {
+    // Test a normal GET API
+    #[get_api]
+    fn greet(name: &String) -> String {
+        format!("Hello {}", name)
+    }
+
+    // Launch server
+    let server_handle = tokio::spawn(async {
+        rocket::build()
+            .mount("/", routes![greet_route])
+            .launch()
+            .await
+    });
+
+    let name = "Sheila".to_string();
+    // Call request
+    let result = greet_request(&name).await;
+    assert_eq!(result, greet(&name));
+
+    server_handle.abort();
+    assert!(server_handle.await.unwrap_err().is_cancelled());
+}
+
 #[tokio::test]
 #[serial_test::serial]
 async fn test_post_api() {
@@ -122,6 +148,34 @@ async fn test_post_api_state() {
         "Hello Frank, I'm here with Joe".to_string()
     );
 
+    server_handle.abort();
+    assert!(server_handle.await.unwrap_err().is_cancelled());
+}
+
+#[tokio::test]
+#[serial_test::serial]
+async fn test_post_api_ref() {
+    // Test POST API with references
+    #[post_api]
+    fn greet(nm: &String, num: &i32) -> String {
+        format!("Hello {}{}", nm, num)
+    }
+
+    // Launch server
+    let server_handle = tokio::spawn(async {
+        rocket::build()
+            .mount("/", routes![greet_route])
+            .manage(Mutex::new("Robert".to_string()))
+            .launch()
+            .await
+    });
+
+    let name = "Gordon Shumway".to_string();
+    assert_eq!(
+        greet_request(&name, &23).await,
+        greet(&name, &23)
+    );
+
     server_handle.abort();
     assert!(server_handle.await.unwrap_err().is_cancelled());
 }
\ No newline at end of file
